==> gsambad_0.1.3.orig.tar.gz: gsambad-0.1.3/src/populate_shell_combo.c <==
/* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
 * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 *
*/




#include "../config.h"
#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "widgets.h"
#include "gettext.h"
#include "allocate.h"
#include "commands.h"
#include "show_info.h"
#include "populate_shell_combo.h"



void populate_shell_combo(GtkWidget *shell_combo)
{
    FILE *fp;
    long conf_size;
    int shell_found = 0;
    char *old_buffy, *new_buffy;
    gchar *utf8=NULL;
    gchar *combo_text=NULL;
    gchar *info;

    /* Append the ...bin/false or ...sbin/nologin shell first and select it */
//    combo_text = g_strdup_printf("/bin/false");
    combo_text = g_strdup_printf("/dev/null");
    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
    gtk_combo_box_append_text(GTK_COMBO_BOX(shell_combo), utf8);    
    gtk_combo_box_set_active(GTK_COMBO_BOX(shell_combo), 0);
    g_free(combo_text);


    if((fp=fopen(SHELLS_FILE, "r"))==NULL)
    {
	info = g_strdup_printf(_("Cant find the shells file here:\n%s\n"), SHELLS_FILE);
	show_info(info);
	g_free(info);
	return;
    }

    fseek(fp, 0, SEEK_END);
    conf_size = ftell(fp);
    rewind(fp);

    old_buffy = allocate(conf_size+1024);
    new_buffy = allocate(conf_size+1024);


    if( conf_size > 1 )
    while(fgets(old_buffy, conf_size, fp)!=NULL)
    {
	if( strstr(old_buffy, "/dev/null") && ! strstr(old_buffy, "#") )
	{
	    shell_found = 1;
	    strcpy(new_buffy, old_buffy);
	    utf8 = g_locale_to_utf8(new_buffy, strlen(new_buffy)-1, NULL, NULL, NULL);
	    gtk_combo_box_append_text(GTK_COMBO_BOX(shell_combo), utf8);
	    break;
	}

	/* Append the /bin/false or /usr/local/bin/false or /usr/bin/false etc shell */
	if( strstr(old_buffy, "false") && ! strstr(old_buffy, "#") )
	{
	    shell_found = 1;
	    strcpy(new_buffy, old_buffy);
	    utf8 = g_locale_to_utf8(new_buffy, strlen(new_buffy)-1, NULL, NULL, NULL);
	    gtk_combo_box_append_text(GTK_COMBO_BOX(shell_combo), utf8);
	    break;
	}

	/* Append the /sbin/nologin or /usr/sbin/nologin or /usr/local/sbin/nologin etc shell */
	if( strstr(old_buffy, "nologin") && ! strstr(old_buffy, "#") )
	{
	    shell_found = 1;
	    strcpy(new_buffy, old_buffy);
	    utf8 = g_locale_to_utf8(new_buffy, strlen(new_buffy)-1, NULL, NULL, NULL);
	    gtk_combo_box_append_text(GTK_COMBO_BOX(shell_combo), utf8);
	    break;
	}

    }


    rewind(fp);


    /* No false or nologin shell found, use /dev/null ? */
    if( ! shell_found )
    {
	info = g_strdup_printf(_("Warning: could not find a false or no login shell here:\n%s\nAppending the other shells."), SHELLS_FILE);
	show_info(info);
	g_free(info);
    }


    /* Append the rest of the shells */
    if( conf_size > 1 )
    while(fgets(old_buffy, conf_size, fp)!=NULL)
    {
	/* Append every shell but the /bin/false shell */   									
	if( ! strstr(old_buffy, "/dev/null") 
	&&  ! strstr(old_buffy, "#") && strlen(old_buffy) > 7 )
	{
	    strcpy(new_buffy, old_buffy);
	    utf8 = g_locale_to_utf8(new_buffy, strlen(new_buffy)-1, NULL, NULL, NULL);
	    gtk_combo_box_append_text(GTK_COMBO_BOX(shell_combo), utf8);    
	}
    }
    fclose(fp);

    free(old_buffy);
    free(new_buffy);

    if( utf8!=NULL )
      g_free(utf8);
}

==> gsambad_0.1.6.orig.tar.gz: gsambad-0.1.6/src/populate_shell_combo.c <==
/* GSAMBAD, an easy to use GTK+ frontend for the SAMBA file and print server.
 * Copyright (C) 2006 Magnus Loef <magnus-swe@telia.com> 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
 *
*/



#include "../config.h"
#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "widgets.h"
#include "gettext.h"
#include "allocate.h"
#include "commands.h"
#include "show_info.h"
#include "populate_shell_combo.h"



void populate_shell_combo(GtkWidget *shell_combo)
{
    FILE *fp;
    long conf_size;
    int shell_found = 0;
    char *line, *new_buf;
    gchar *utf8=NULL;
    gchar *combo_text=NULL;
    gchar *info;

    /* Append a /dev/null shell first and select it */
    combo_text = g_strdup_printf("/dev/null");
    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
    gtk_combo_box_append_text(GTK_COMBO_BOX(shell_combo), utf8);    
    gtk_combo_box_set_active(GTK_COMBO_BOX(shell_combo), 0);
    g_free(combo_text);

    if((fp=fopen(SHELLS_FILE, "r"))==NULL)
    {
	info = g_strdup_printf(_("Cant find the shells file here:\n%s\n"), SHELLS_FILE);
	show_info(info);
	g_free(info);
	return;
    }
    fseek(fp, 0, SEEK_END);
    conf_size = ftell(fp);
    rewind(fp);

    line = allocate(conf_size+2);
    new_buf = allocate(conf_size+2);

    if( conf_size > 1 )
    while(fgets(line, conf_size, fp)!=NULL)
    {
	/* Append all other shells but not /dev/null */
	if( strlen(line) > 3 && ! strstr(line, "#") && ! strstr(line, "/dev/null") )
	{
	    shell_found = 1;
	    strcpy(new_buf, line);
	    utf8 = g_locale_to_utf8(new_buf, strlen(new_buf)-1, NULL, NULL, NULL);
	    gtk_combo_box_append_text(GTK_COMBO_BOX(shell_combo), utf8);
	}
    }
    fclose(fp);
    free(line);
    free(new_buf);

    if( utf8!=NULL )
      g_free(utf8);
}
